NativeClient

Struct NativeClient 

pub struct NativeClient<'a> { /* private fields */ }
Access to venue-specific adapter functionality.

Implementations

Source

impl<'a> NativeClient<'a>

pub fn binance(&self) -> Result<&BinanceLinearFuturesAdapter>

Return the Binance adapter when this client was built for Binance.

pub fn bybit(&self) -> Result<&BybitLinearFuturesAdapter>

Return the Bybit adapter when this client was built for Bybit.

pub fn mexc(&self) -> Result<&MexcLinearFuturesAdapter>

Return the MEXC adapter when this client was built for MEXC.