pub struct NativeClient<'a> { /* private fields */ }Expand description
Access to venue-specific adapter functionality.
Implementations
Sourceimpl<'a> NativeClient<'a>
impl<'a> NativeClient<'a>
Sourcepub fn binance(&self) -> Result<&BinanceLinearFuturesAdapter>
pub fn binance(&self) -> Result<&BinanceLinearFuturesAdapter>
Return the Binance adapter when this client was built for Binance.
Sourcepub fn bybit(&self) -> Result<&BybitLinearFuturesAdapter>
pub fn bybit(&self) -> Result<&BybitLinearFuturesAdapter>
Return the Bybit adapter when this client was built for Bybit.
Sourcepub fn mexc(&self) -> Result<&MexcLinearFuturesAdapter>
pub fn mexc(&self) -> Result<&MexcLinearFuturesAdapter>
Return the MEXC adapter when this client was built for MEXC.